#-------------------------------------------------------------------------------------------------------------------------------------

# CIS - Community Innovation Survey 3 - Data without Boundaries (Work Package 5)

# This routine processes CIS 3 Norway data formatted in CSV.
# Checked for the July 2013 release of the CIS, as provided by Eurostat.

# Version 1 of the routine, March 2015
# R 3.1.3

# University of Ljubljana, Social Science Data Archives, partners of Data without Boundaries project
# Sebastian Kocar
# http://www.adp.fdv.uni-lj.si/
# Contact: arhiv.podatkov@fdv.uni-lj.si

# This R code is protected under the creative commons license.

#-------------------------------------------------------------------------------------------------------------------------------------

# --- EXCEL DATA EXPORT---

# To use this R code, CIS 3 Norway Excel 1997-2003 data file has to be exported/saved as 
# CSV data file in Microsoft Office Excel (with a comma as a separator and a dot as a decimal 
# separator, with no exceptions!). 
# PLEASE NOTE that decimal separators in Excel should be set to commas (,) before saving the dataset as
# a CSV dataset. After that the following two actions should be done in that specific order using
# a text editor: (1) replacing  commas (,) with dots (.), (2) replacing semicolons (;) with commas (,).
# The database in .csv format should then be imported into SPSS and later processed using  the
# commands below.

#-------------------------------------------------------------------------------------------------------------------------------------



# --- CONFIGURATION SECTION - START ---


# The following command should contain the complete path and
# name of the .csv file to be read (e.g. "C:/CIS 2008/Data/ALL.csv")
# Change CSV_DATA_PATH to your filename, below:

csvpath <- "CSV_DATA_PATH"


# The following command should contain the complete path and
# name of the .Rdata file to be saved (e.g. "C:/CIS 2008/Data/ALL.Rdata")
# Change RDATA_PATH to your filename, below:

rdatapath <- "RDATA_PATH"


# --- CONFIGURATION SECTION -  END  ---

# ------------------------------------------------------------------------------



# There should be nothing to change below this line
# ------------------------------------------------------------------------------



# --- Read the raw data ---

rdatafile <- read.csv(csvpath, sep = ",")

names(rdatafile) <- toupper(names(rdatafile))    # all variable names to upper case


# ------------------------------------------------------------------------------



# --- Recode string variables which have labels, to numeric variables ---

NACE2_N <- rdatafile[ , "NACE2_N"]
tempvar <- rep(NA, length(NACE2_N))

tempvar[NACE2_N == "10"] <- 1
tempvar[NACE2_N == "10_11"] <- 2
tempvar[NACE2_N == "10_11_12"] <- 3
tempvar[NACE2_N == "10_11_13"] <- 4
tempvar[NACE2_N == "10_11_14"] <- 5
tempvar[NACE2_N == "10_14"] <- 6
tempvar[NACE2_N == "11_12_14"] <- 7
tempvar[NACE2_N == "11_14"] <- 8
tempvar[NACE2_N == "12_13"] <- 9
tempvar[NACE2_N == "13_14"] <- 10
tempvar[NACE2_N == "14"] <- 11
tempvar[NACE2_N == "14_15"] <- 12
tempvar[NACE2_N == "15"] <- 13
tempvar[NACE2_N == "15_15"] <- 14
tempvar[NACE2_N == "15_16"] <- 15
tempvar[NACE2_N == "16"] <- 16
tempvar[NACE2_N == "17"] <- 17
tempvar[NACE2_N == "17_18"] <- 18
tempvar[NACE2_N == "18"] <- 19
tempvar[NACE2_N == "18_19"] <- 20
tempvar[NACE2_N == "19"] <- 21
tempvar[NACE2_N == "19_20"] <- 22
tempvar[NACE2_N == "20"] <- 23
tempvar[NACE2_N == "20_21"] <- 24
tempvar[NACE2_N == "20_21_22"] <- 25
tempvar[NACE2_N == "21"] <- 26
tempvar[NACE2_N == "22"] <- 27
tempvar[NACE2_N == "22_23"] <- 28
tempvar[NACE2_N == "23"] <- 29
tempvar[NACE2_N == "23_24"] <- 30
tempvar[NACE2_N == "24"] <- 31
tempvar[NACE2_N == "24_25"] <- 32
tempvar[NACE2_N == "25"] <- 33
tempvar[NACE2_N == "26"] <- 34
tempvar[NACE2_N == "26_27"] <- 35
tempvar[NACE2_N == "27"] <- 36
tempvar[NACE2_N == "27_28"] <- 37
tempvar[NACE2_N == "28"] <- 38
tempvar[NACE2_N == "29"] <- 39
tempvar[NACE2_N == "30"] <- 40
tempvar[NACE2_N == "30_31"] <- 41
tempvar[NACE2_N == "31"] <- 42
tempvar[NACE2_N == "31_33"] <- 43
tempvar[NACE2_N == "32"] <- 44
tempvar[NACE2_N == "33"] <- 45
tempvar[NACE2_N == "33_34"] <- 46
tempvar[NACE2_N == "34"] <- 47
tempvar[NACE2_N == "34_35"] <- 48
tempvar[NACE2_N == "35"] <- 49
tempvar[NACE2_N == "36"] <- 50
tempvar[NACE2_N == "36_37"] <- 51
tempvar[NACE2_N == "36_40_41"] <- 52
tempvar[NACE2_N == "37"] <- 53
tempvar[NACE2_N == "40"] <- 54
tempvar[NACE2_N == "40_41"] <- 55
tempvar[NACE2_N == "41"] <- 56
tempvar[NACE2_N == "51"] <- 57
tempvar[NACE2_N == "60"] <- 58
tempvar[NACE2_N == "60_61"] <- 59
tempvar[NACE2_N == "60_61_62"] <- 60
tempvar[NACE2_N == "61"] <- 61
tempvar[NACE2_N == "61_62"] <- 62
tempvar[NACE2_N == "62"] <- 63
tempvar[NACE2_N == "62_63"] <- 64
tempvar[NACE2_N == "63"] <- 65
tempvar[NACE2_N == "63_64"] <- 66
tempvar[NACE2_N == "64"] <- 67
tempvar[NACE2_N == "64_65_66_67"] <- 68
tempvar[NACE2_N == "65"] <- 69
tempvar[NACE2_N == "65_66_67"] <- 70
tempvar[NACE2_N == "66"] <- 71
tempvar[NACE2_N == "66_67"] <- 72
tempvar[NACE2_N == "67"] <- 73
tempvar[NACE2_N == "72"] <- 74
tempvar[NACE2_N == "72_73"] <- 75
tempvar[NACE2_N == "73"] <- 76
tempvar[NACE2_N == "74"] <- 77

rdatafile[ , "NACE2_N"] <- tempvar

SIZE98_N <- rdatafile[ , "SIZE98_N"]
tempvar <- rep(NA, length(SIZE98_N))

tempvar[SIZE98_N == "       0"] <- 1
tempvar[SIZE98_N == "       1"] <- 2
tempvar[SIZE98_N == "       2"] <- 3
tempvar[SIZE98_N == "       3"] <- 4
tempvar[SIZE98_N == "0_1"] <- 5
tempvar[SIZE98_N == "0_1_2"] <- 6
tempvar[SIZE98_N == "0_1_2_3"] <- 7
tempvar[SIZE98_N == "0_1_2.3"] <- 8
tempvar[SIZE98_N == "0_1_3"] <- 9
tempvar[SIZE98_N == "0_2"] <- 10
tempvar[SIZE98_N == "0_2_3"] <- 11
tempvar[SIZE98_N == "0.1_2"] <- 12
tempvar[SIZE98_N == "1_2"] <- 13
tempvar[SIZE98_N == "1_2_3"] <- 14
tempvar[SIZE98_N == "1_3"] <- 15
tempvar[SIZE98_N == "2_3"] <- 16

rdatafile[ , "SIZE98_N"] <- tempvar

SIZE00_N <- rdatafile[ , "SIZE00_N"]
tempvar <- rep(NA, length(SIZE00_N))

tempvar[SIZE00_N == "       1"] <- 1
tempvar[SIZE00_N == "       2"] <- 2
tempvar[SIZE00_N == "       3"] <- 3
tempvar[SIZE00_N == "1_2"] <- 4
tempvar[SIZE00_N == "1_2_3"] <- 5
tempvar[SIZE00_N == "1_3"] <- 6
tempvar[SIZE00_N == "2_3"] <- 7

rdatafile[ , "SIZE00_N"] <- tempvar


# ------------------------------------------------------------------------------



# --- Force variables as numeric ---

rdatafile[ , "TURN98"] <- suppressWarnings(as.numeric(rdatafile[ , "TURN98"]))
rdatafile[ , "EXP"]    <- suppressWarnings(as.numeric(rdatafile[ , "EXP"]))
rdatafile[ , "INVTA"]  <- suppressWarnings(as.numeric(rdatafile[ , "INVTA"]))
rdatafile[ , "RRDINX"] <- suppressWarnings(as.numeric(rdatafile[ , "RRDINX"]))
rdatafile[ , "RRDEXX"] <- suppressWarnings(as.numeric(rdatafile[ , "RRDEXX"]))
rdatafile[ , "RMACX"]  <- suppressWarnings(as.numeric(rdatafile[ , "RMACX"]))
rdatafile[ , "ROEKX"]  <- suppressWarnings(as.numeric(rdatafile[ , "ROEKX"]))
rdatafile[ , "ROTHX"]  <- suppressWarnings(as.numeric(rdatafile[ , "ROTHX"]))
rdatafile[ , "RTOT"]   <- suppressWarnings(as.numeric(rdatafile[ , "RTOT"]))
rdatafile[ , "RDPER"]  <- suppressWarnings(as.numeric(rdatafile[ , "RDPER"]))



# ------------------------------------------------------------------------------


# --- Set the variable labels attribute ---
#--- Please note that the reference period is not 1998-2000 for all countries. Please check CIS 3 
# country level metadata.


attr(rdatafile, "variable labels") <- list(
"NUTS_2DIG" = "Country",
"NACE2_N"   = "Main activity",
"GP"        = "Enterprise part of a group",
"C_HO"      = "Country of head office",
"EST"       = "Establishment of enterprise between 1998 and 2000",
"TURNINC"   = "Turnover increased 1998-2000",
"TURNDEC"   = "Turnover decreased 1998-2000",
"SIGMAR"    = "Most significant markets in 1998-2000",
"TURN98"    = "Total turnover in 1998",
"TURN"      = "Total turnover in 2000",
"EXP98"     = "Export in 1998",
"EXP"       = "Export in 2000",
"INVTA"     = "Gross investment in tangible goods in 2000",
"SIZE98_N"  = "Total number of employees in 1998",
"SIZE00_N"  = "Total number of employees in 2000",
"EMPHI"     = "Total number of employees in 2000, of which: with higher education",
"INPDT"     = "Introduced onto the market a new or significantly improved goods or services",
"INPDTW"    = "Who mainly developed these products",
"TURNIN"    = "% of turnover in  unchanged or marginally modified products during 1998-2000 that were new to the firm",
"TURNUNG"   = "% of turnover in  unchanged or marginally modified products during 1998-2000",
"INMAR"     = "Introducing new or significantly improved products, new for the enterprise's market",
"TURNMAR"   = "% of turnover in new or improved products introduced during 1998-2000 that were new to the market",
"INPCS"     = "Introduced onto the market a new or significantly improved method of production",
"INPCSW"    = "Who mainly developed these processes",
"INON"      = "Enterprise with ongoing or abandoned innovation activities",
"INAB"      = "Abandoned or suspended before completion",
"RRDIN"     = "Engagement in intramural R&D",
"RRDINX"    = "Expenditure in intramural R&D",
"RRDEX"     = "Engagement in extramural R&D",
"RRDEXX"    = "Purchase of extramural R&D",
"RMAC"      = "Engagement in acquisition of machinery",
"RMACX"     = "Expenditure in acquisition of machinery",
"ROEK"      = "Engagement in acquisition of external knowledge",
"ROEKX"     = "Expenditure in acquisition of external knowledge",
"RTR"       = "Engagement in training for innovative activities",
"RMAR"      = "Engagement in market introduction of innovation",
"RPRE"      = "Engagement in other preparation",
"ROTHX"     = "Other expenditure (in training, market innovation, design)",
"RTOT"      = "Total of these four innovation expenditure categories",
"RDPER"     = "People involved in R&D in 2000",
"RDENG"     = "Type of engagement in R&D",
"ERANGE"    = "Increased range of goods or services",
"EMAR"      = "Increased market or market share",
"EQUA"      = "Improved quality in goods or services",
"EFLEX"     = "Improved production flexibility",
"ECAP"      = "Improved production capacity",
"ELBR"      = "Reduced labour costs per produced unit",
"EMAT"      = "Reduced materials and energy per produced unit",
"EENV"      = "Reduced environmental impact or health and safety aspects",
"ESTD"      = "Met regulations or standards",
"FUNLOC"    = "Public funding from local or regional authorities",
"FUNGMT"    = "Public funding from central government",
"FUNEU"     = "Public funding from the EU",
"FUNRTD"    = "Funding from EU's 4th, 5th, 6th or 7th Framework Programme for RTD",
"CO"        = "Cooperation arrangements on innovation activities",
"CO11"      = "Other enterprises within enterprise group : National",
"CO12"      = "Other enterprises within enterprise group : EU/EFTA",
"CO13"      = "Other enterprises within enterprise group : EU-CC",
"CO14"      = "Other enterprises within enterprise group : US",
"CO15"      = "Other enterprises within enterprise group : Japan",
"CO16"      = "Other enterprises within enterprise group : Other countries",
"CO21"      = "Suppliers of equipment, etc. : National",
"CO22"      = "Suppliers of equipment, etc. : EU/EFTA",
"CO23"      = "Suppliers of equipment, etc. : EU-CC",
"CO24"      = "Suppliers of equipment, etc. : US",
"CO25"      = "Suppliers of equipment, etc. : Japan",
"CO26"      = "Suppliers of equipment, etc. :  Other countries",
"CO31"      = "Clients or customers : National",
"CO32"      = "Clients or customers : EU/EFTA",
"CO33"      = "Clients or customers : EU-CC",
"CO34"      = "Clients or customers : US",
"CO35"      = "Clients or customers : Japan",
"CO36"      = "Clients or customers : Other countries",
"CO41"      = "Competitors or other firms  : National",
"CO42"      = "Competitors or other firms  : EU/EFTA",
"CO43"      = "Competitors or other firms  : EU-CC",
"CO44"      = "Competitors or other firms  : US",
"CO45"      = "Competitors or other firms  : Japan",
"CO46"      = "Competitors or other firms  : Other countries",
"CO51"      = "Consultants: National",
"CO52"      = "Consultants: EU/EFTA",
"CO53"      = "Consultants: EU-CC",
"CO54"      = "Consultants: US",
"CO55"      = "Consultants: Japan",
"CO56"      = "Consultants: Other countries",
"CO61"      = "Commercial laboratories /R&D enterprises : National",
"CO62"      = "Commercial laboratories /R&D enterprises : EU/EFTA",
"CO63"      = "Commercial laboratories /R&D enterprises : EU-CC",
"CO64"      = "Commercial laboratories /R&D enterprises : US",
"CO65"      = "Commercial laboratories /R&D enterprises : Japan",
"CO66"      = "Commercial laboratories /R&D enterprises : Other countries",
"CO71"      = "Universities or other  : National",
"CO72"      = "Universities or other  : EU/EFTA",
"CO73"      = "Universities or other  : EU-CC",
"CO74"      = "Universities or other  : US",
"CO75"      = "Universities or other  : Japan",
"CO76"      = "Universities or other  : Other countries",
"CO81"      = "Government or public research institutes: National",
"CO82"      = "Government or public research institutes:  EU/EFTA",
"CO83"      = "Government or public research institutes:  EU-CC",
"CO84"      = "Government or public research institutes: US",
"CO85"      = "Government or public research institutes: Japan",
"CO86"      = "Government or public research institutes: Other countries",
"SENT"      = "Sources from within the enterprise",
"SGRP"      = "Sources from other enterprises within the enterprise group",
"SSUP"      = "Sources from Suppliers of equipment, materials, etc.",
"SCLI"      = "Sources from Clients or customers",
"SCOM"      = "Sources from Competitors and other enterprises of same industry",
"SUNI"      = "Sources from Universities or other higher education institutes",
"SGMT"      = "Sources from Government or public research institutes",
"SPRO"      = "Sources from Professional and industry associations",
"SEXB"      = "Sources from fairs, exhibitions",
"HDLAY"     = "Innovation activity seriously delayed",
"HSTAR"     = "Innovation activity prevented to be started",
"HBUR"      = "Innovation activity burdened/cumbered with other serious problems",
"HPRIOR"    = "No innovation activity due to prior innovations",
"HMAR"      = "No innovation activity due to no demand for innovations",
"HIMP"      = "No innovation activity due to factors impeding innovation?",
"HECO"      = "Hampering factor : Excessive perceived economic risks",
"HCOS"      = "Hampering factor : Innovation costs too high",
"HFIN"      = "Hampering factor : Lack of appropriate sources of finance",
"HORG"      = "Hampering factor : Organisational rigidities within the enterprise",
"HPER"      = "Hampering factor : Lack of qualified personnel",
"HTEC"      = "Hampering factor : Lack of information on technology",
"HINF"      = "Hampering factor : Lack of information on markets",
"HFLEX"     = "Hampering factor : Insufficient flexibility of regulations or standards",
"HCUS"      = "Hampering factor : Lack of customer responsiveness to new goods or services",
"PAAP"      = "Applied for a patent",
"PAVAL"     = "Having valid patents",
"PROREG"    = "Registration of design patterns",
"PROTM"     = "Register a trademark",
"PROCP"     = "Claimed copyright",
"PROSEC"    = "Protecting inventions or innovations by Secrecy",
"PRODES"    = "Protecting inventions or innovations by Complexity of design",
"PROTIM"    = "Protecting inventions or innovations by Lead-time advantage on competitors",
"ACTSTR"    = "Strategical changes",
"ACTMAN"    = "Management changes",
"ACTORG"    = "Organizational changes",
"ACTMAR"    = "Marketing changes",
"ACTAES"    = "Aesthetic changes (or other subjective changes)",
"W2USE"     = "Weighting factor")


# ------------------------------------------------------------------------------



# --- Set the value labels attribute --- 

attr(rdatafile, "value labels") <- vector(mode="list", length=123)

attr(rdatafile, "value labels")[1] <- list(c(
    "No answer" = 0,
    "Home Country" = 1,
    "EU, EFTA, CC" = 2,
    "rest of the world" = 3
))

names(attr(rdatafile, "value labels"))[1] <- "C_HO"

attr(rdatafile, "value labels")[2:41] <- rep(list(c(
    "No" = 0,
    "Yes" = 1
)), 40)

names(attr(rdatafile, "value labels"))[2:41] <- c(
    "GP", "EST", "TURNINC", "TURNDEC", "INPDT", "INMAR", "INPCS", "INON", "INAB", "RRDIN",
    "RRDEX", "RMAC", "ROEK", "RTR", "RMAR", "RPRE", "FUNLOC", "FUNGMT", "FUNEU", "FUNRTD",
    "CO", "HDLAY", "HSTAR", "HBUR", "HPRIOR", "HMAR", "HIMP", "PAAP", "PAVAL", "PROREG",
    "PROTM", "PROCP", "PROSEC", "PRODES", "PROTIM", "ACTSTR", "ACTMAN", "ACTORG", "ACTMAR",
    "ACTAES"
)

attr(rdatafile, "value labels")[42] <- list(c(
    "Local/ regional (within a distance of around 50 km) within your country" = 1,
    "Local/ regional (within a distance of around 50 km) within your neighbouring countries" = 2,
    "National (with a distance of more than 50 km)" = 3,
    "International (with a distance of more than 50 km)" = 4
))

names(attr(rdatafile, "value labels"))[42] <- "SIGMAR"

attr(rdatafile, "value labels")[43:44] <- rep(list(c(
    "Mainly your enterprise or enterprise group" = 1,
    "Your enterprise in co-operation with other enterprises or institutions" = 2,
    "Mainly other enterprises or institutions" = 3
)), 2)

names(attr(rdatafile, "value labels"))[43:44] <- c(
    "INPDTW", "INPCSW"
)

attr(rdatafile, "value labels")[45] <- list(c(
    "Continuously" = 1,
    "Occasionally" = 2
))

names(attr(rdatafile, "value labels"))[45] <- "RDENG"

attr(rdatafile, "value labels")[46:63] <- rep(list(c(
    "Not relevant" = 0,
    "Low" = 1,
    "Med" = 2,
    "High" = 3
)), 18)

names(attr(rdatafile, "value labels"))[46:63] <- c(
    "ERANGE", "EMAR", "EQUA", "EFLEX", "ECAP", "ELBR", "EMAT", "EENV", "ESTD", "HECO",
    "HCOS", "HFIN", "HORG", "HPER", "HTEC", "HINF", "HFLEX", "HCUS"
)

attr(rdatafile, "value labels")[64:111] <- rep(list(c(
    "Not selected" = 0,
    "Selected" = 1
)), 48)

names(attr(rdatafile, "value labels"))[64:111] <- c(
    "CO11", "CO12", "CO13", "CO14", "CO15", "CO16", "CO21", "CO22", "CO23", "CO24", "CO25",
    "CO26", "CO31", "CO32", "CO33", "CO34", "CO35", "CO36", "CO41", "CO42", "CO43", "CO44",
    "CO45", "CO46", "CO51", "CO52", "CO53", "CO54", "CO55", "CO56", "CO61", "CO62", "CO63",
    "CO64", "CO65", "CO66", "CO71", "CO72", "CO73", "CO74", "CO75", "CO76", "CO81", "CO82",
    "CO83", "CO84", "CO85", "CO86"
)

attr(rdatafile, "value labels")[112:120] <- rep(list(c(
    "Not used" = 0,
    "Low" = 1,
    "Med" = 2,
    "High" = 3
)), 9)

names(attr(rdatafile, "value labels"))[112:120] <- c(
    "SENT", "SGRP", "SSUP", "SCLI", "SCOM", "SUNI", "SGMT", "SPRO", "SEXB"
)

attr(rdatafile, "value labels")[121] <- list(c(
    "Mining of coal and lignite; extraction of peat" = 1,
    "Mining of coal, lignite; extraction of peat, crude petroleum, gas; service activities incidental to oil, gas extraction" = 2,
    "Mining and quarrying of energy producing materials" = 3,
    "Mining of coal, lignite, uranium, metal ores; extraction of peat, crude petroleum and natural gas" = 4,
    "Mining of coal, lignite, uranium, other mining; extraction of peat, crude petroleum and natural gas" = 5,
    "Mining of coal and lignite; extraction of peat; other mining and quarrying" = 6,
    "Extraction of crude petroleum and natural gas; Mining of uranium and thorium ores; Other mining and quarrying" = 7,
    "Extraction of crude petroleum and natural gas; Other mining and quarrying" = 8,
    "Mining of uranium and thorium ores; Mining of metal ores" = 9,
    "Mining and quarrying, except of energy producing materials" = 10,
    "Other mining and quarrying" = 11,
    "Other mining and quarrying; Manufacture of food products and beverages" = 12,
    "Manufacture of food products and beverages" = 13,
    "Manufacture of food products, beverages and tobacco (Portuguese coding)" = 14,
    "Manufacture of food products, beverages and tobacco" = 15,
    "Manufacture of tobacco products" = 16,
    "Manufacture of textiles" = 17,
    "Manufacture of textiles and textile products" = 18,
    "Manufacture of wearing apparel; dressing and dyeing of fur" = 19,
    "Manufacture of wearing apparel, luggage/handbags/saddlery/harness/footwear; dressing, dyeing of fur; tanning of leather" = 20,
    "Manufacture of leather and leather products" = 21,
    "Manufacture of leather and leather products; Manufacture of wood and wood products" = 22,
    "Manufacture of wood and wood products" = 23,
    "Manufacture of wood and wood products; Manufacture of pulp, paper and paper products" = 24,
    "Manufacture of wood and wood products; Manufacture of pulp, paper and paper products; publishing and printing" = 25,
    "Manufacture of pulp, paper and paper products" = 26,
    "Publishing, printing and reproduction of recorded media" = 27,
    "Publishing, printing , reproduction of recorded media;  Manufacture of coke, refined petroleum products and nuclear fuel" = 28,
    "Manufacture of coke, refined petroleum products and nuclear fuel" = 29,
    "Manufacture of coke, refined petroleum products and nuclear fuel; Manufacture of chemicals and chemical products" = 30,
    "Manufacture of chemicals and chemical products" = 31,
    "Manufacture of chemicals and chemical products; Manufacture of rubber and plastic products" = 32,
    "Manufacture of rubber and plastic products" = 33,
    "Manufacture of other non-metallic mineral products" = 34,
    "Manufacture of other non-metallic mineral products;  Manufacture of basic metals" = 35,
    "Manufacture of basic metals" = 36,
    "Manufacture of basic metals and fabricated metal products" = 37,
    "Manufacture of fabricated metal products, except machinery and equipment" = 38,
    "Manufacture of machinery and equipment n.e.c." = 39,
    "Manufacture of office machinery and computers" = 40,
    "Manufacture of office machinery and computers; manufacture of electrical machinery and apparatus n.e.c." = 41,
    "Manufacture of electrical machinery and apparatus n.e.c." = 42,
    "Manufacture of electrical machinery and apparatus n.e.c.; medical, precision and optical instruments, watches and clocks" = 43,
    "Manufacture of radio, television and communication equipment and apparatus" = 44,
    "Manufacture of medical, precision and optical instruments, watches and clocks" = 45,
    "Manufacture of medical, precision and optical instruments, watches, clocks; of motor vehicles, trailers, semi-trailers" = 46,
    "Manufacture of motor vehicles, trailers and semi-trailers" = 47,
    "Manufacture of transport equipment" = 48,
    "Manufacture of other transport equipment" = 49,
    "Manufacture of furniture; manufacturing n.e.c." = 50,
    "Manufacture of furniture; manufacturing n.e.c.; Recycling" = 51,
    "Manufacture of furniture; manufacturing n.e.c.;  Electricity, gas and water supply" = 52,
    "Recycling" = 53,
    "Electricity, gas, steam and hot water supply" = 54,
    "Electricity, gas, steam and hot water supply; collection, purification and distribution of water" = 55,
    "Collection, purification and distribution of water" = 56,
    "Wholesale trade and commission trade, except of motor vehicles and motorcycles" = 57,
    "Land transport; transport via pipelines" = 58,
    "Land transport; transport via pipelines; Water transport" = 59,
    "Land transport; transport via pipelines; Water transport; Air transport" = 60,
    "Water transport" = 61,
    "Water transport; Air transport" = 62,
    "Air transport" = 63,
    "Air transport; Supporting and auxiliary transport activities; activities of travel agencies" = 64,
    "Supporting and auxiliary transport activities; activities of travel agencies" = 65,
    "Supporting and auxiliary transport activities; activities of travel agencies; Post and telecommunications" = 66,
    "Post and telecommunications" = 67,
    "Post and telecommunications; Financial intermediation" = 68,
    "Financial intermediation, except insurance and pension funding" = 69,
    "Financial intermediation" = 70,
    "Insurance and pension funding, except compulsory social security" = 71,
    "Insurance and pension funding, except compulsory social security;  Activities auxiliary to financial intermediation" = 72,
    "Activities auxiliary to financial intermediation" = 73,
    "Computer and related activities" = 74,
    "Computer and related activities; Research and development" = 75,
    "Research and development" = 76,
    "Other business activities" = 77
))

names(attr(rdatafile, "value labels"))[121] <- "NACE2_N"

attr(rdatafile, "value labels")[122] <- list(c(
    "10-19" = 1,
    "20-49" = 2,
    "50-249" = 3,
    "250+" = 4,
    "10-49" = 5,
    "10-249" = 6,
    "10+" = 7,
    "10+" = 8,
    "10-49 & 250+" = 9,
    "10-19 & 50-249" = 10,
    "10-19 & 50+" = 11,
    "10-249" = 12,
    "20-249" = 13,
    "20+" = 14,
    "20-49 & 250+" = 15,
    "50+" = 16
))

names(attr(rdatafile, "value labels"))[122] <- "SIZE98_N"

attr(rdatafile, "value labels")[123] <- list(c(
    "10-49" = 1,
    "50-249" = 2,
    "250+" = 3,
    "10-249" = 4,
    "10+" = 5,
    "10-49 & 250+" = 6,
    "50+" = 7
))

names(attr(rdatafile, "value labels"))[123] <- "SIZE00_N"


# ------------------------------------------------------------------------------



# --- Save the R data file --- 

rfilename <- unlist(strsplit(basename(rdatapath), split="\\."))[1]
rdatapath <- file.path(dirname(rdatapath), paste(rfilename, ".Rdata", sep=""))
assign(rfilename, rdatafile)
eval(parse(text = paste("save(", rfilename, ", file=rdatapath)", sep="")))


# ------------------------------------------------------------------------------



# --- Clean up the working space --- 

rm(rfilename, rdatafile, csvpath, rdatapath, tempvar, NACE2_N, SIZE98_N, SIZE00_N)


# ------------------------------------------------------------------------------



